
import bb.cascades 1.0
import bb.system 1.0
import bb.multimedia 1.0
import bb.device 1.0
import QtQuick 1.0

NavigationPane {
    id: navigationPane

    onPopTransitionEnded: {
        Application.menuEnabled = true
        if (page.objectName == "SettingsPage") {
            page.save()
            updateGuiFromSettings()
        }
        page.destroy()
    }
    Menu.definition: MenuDefinition {
        actions: [
            ActionItem {
                title: qsTr("About")
                imageSource: "asset:///images/info.png"
                onTriggered: {
                    Application.menuEnabled = false
                    var page = aboutPageDefinition.createObject();
                    push(page);
                }
            },
            ActionItem {
                id: settingsAction
                ActionBar.placement: ActionBarPlacement.OnBar
                title: qsTr("Settings")
                imageSource: "asset:///images/settings.png"
                onTriggered: {
                    Application.menuEnabled = false
                    var page = settingsPageDefinition.createObject();
                    push(page);
                }
            }
        ]
    }

    function updateShareUri() {
        shareAction.enabled = desktopCamera.lastRecordedFile().length

        shareAction.query.uri = "file://" + desktopCamera.lastRecordedFile()
        shareAction.query.updateQuery();

        playAction.enabled = shareAction.enabled
        deleteAction.enabled = shareAction.enabled

        infoContainer.visible = shareAction.enabled
    }

    function showMessage(message) {
        popupMessage.body = message
        popupMessage.show()
    }

    function updateGuiFromSettings() {

    }

    function updateRecordedInfo() {
        fileSizeLabel.text = desktopCamera.recordedFileSizeString()
        recordTimeLabel.text = desktopCamera.recordedTimeString()
        recordedInfoFileNameLabel.text = desktopCamera.lastRecordedFileNameString()
    }

    Page {
        titleBar: TitleBar {
            id: titleBar
            title: penzus.officialAppName()
            visibility: ChromeVisibility.Visible
            scrollBehavior: TitleBarScrollBehavior.Sticky
        }

        Container {
            topPadding: 20
            bottomPadding: 20
            leftMargin: 20
            leftPadding: 20
            rightMargin: 20
            rightPadding: 20
            bottomMargin: 20
            layout: DockLayout {
            }
            Label {
                id: infoLabel
                text: qsTr("To start record, press the \"Start record\" button or the \"Play/Pause\" key. All files will be saved to the 'camera' directory.")
                multiline: true
                visible: ! recordButton.recorded
                textStyle.color: Color.Gray
                horizontalAlignment: HorizontalAlignment.Center
            }
            Container {
                verticalAlignment: VerticalAlignment.Center
                horizontalAlignment: HorizontalAlignment.Center
                Button {
                    property bool recorded: false
                    id: recordButton
                    text: ! recorded ? qsTr("Start record") : qsTr("Stop record")
                    function toggleRecord() {
                        enabled = false
                        if (! recorded) {
                            showMessage(qsTr("Record started"))
                            recorded = desktopCamera.onStartCameraRecord()
                            updateRecordedInfo()
                            shareAction.enabled = false
                            playAction.enabled = false

                            if (! recorded) {
                                popupMessage.cancel()
                                warningDialog.show()
                                return
                            } else {
                                infoContainer.visible = true
                            }
                            ledID.flash()
                        } else {
                            showMessage(qsTr("Record stopped"))
                            desktopCamera.onStopCameraRecord();
                            recorded = false
                            updateShareUri()
                            ledID.cancel()
                        }
                        enabled = true
                    }
                    onClicked: {
                        toggleRecord()
                    }
                }
            }
            Container {
                id: infoContainer
                verticalAlignment: VerticalAlignment.Bottom
                horizontalAlignment: HorizontalAlignment.Center
                Label {
                    id: recordedInfoFileNameLabel
                    textStyle.color: Color.Gray
                    horizontalAlignment: HorizontalAlignment.Center
                }
                Label {
                    id: recordTimeLabel
                    textStyle.color: Color.Gray
                    horizontalAlignment: HorizontalAlignment.Center
                }
                Label {
                    id: fileSizeLabel
                    textStyle.color: Color.Gray
                    horizontalAlignment: HorizontalAlignment.Center
                }

            }
        }
        actions: [
            ActionItem {
                id: playAction
                enabled: false
                title: qsTr("Play")
                imageSource: "asset:///images/play.png"
                ActionBar.placement: ActionBarPlacement.OnBar
                onTriggered: {
                    penzus.openPlayVideoFile(desktopCamera.lastRecordedFile())
                }
            },
            /*
             * ActionItem {
             * id: editAction
             * enabled: false
             * title: qsTr("Edit")
             * imageSource: "asset:///images/edit.png"
             * ActionBar.placement: ActionBarPlacement.OnBar
             * onTriggered: {
             * penzus.openEditVideoFile(desktopCamera.lastRecordedFile())
             * }
             * },*/

            InvokeActionItem {
                id: shareAction
                enabled: false
                ActionBar.placement: ActionBarPlacement.OnBar
                query.mimeType: "video/mp4"
                query.invokeActionId: "bb.action.SHARE"
                query.uri: "file:///1.mp4"
                onTriggered: {
                }
            },

            ActionItem {
                id: deleteAction
                enabled: false
                imageSource: "asset:///images/delete.png"
                ActionBar.placement: ActionBarPlacement.OnBar
                onTriggered: {
                    deleteConfirmDialog.invoke()

                }
            }
        ]
        attachedObjects: [
            Connections {
                target: desktopCamera
                onTimerEvent: {
                    updateRecordedInfo()
                }
            },
            SystemDialog {
                id: deleteConfirmDialog
                title: qsTr("Warning")
                cancelButton.label: qsTr("Cancel")
                confirmButton.label: qsTr("Delete")
                property int itemID
                function invoke(ID, title) {
                    popupMessage.cancel()
                    body = qsTr("Do you really want to delete the file?")
                    show()
                }
                onFinished: {
                    if (result == SystemUiResult.ConfirmButtonSelection) {
                        if (penzus.deleteVideoFile(desktopCamera.lastRecordedFile())) {
                            showMessage(qsTr("File deleted successfully"))
                        } else {
                            showMessage(qsTr("Error deleting file"))
                        }
                        desktopCamera.clearLastRecordedFile()
                        updateShareUri()
                    }
                }
            },
            MediaKeyWatcher {
                id: keyWatcher
                key: MediaKey.PlayPause
                onShortPress: {
                    recordButton.toggleRecord()
                }
            },
            Led {
                id: ledID
                color: LedColor.Blue
            },
            SystemToast {
                id: popupMessage
            },
            SystemDialog {
                id: warningDialog
                title: qsTr("Warning")
                body: qsTr("Cannot open camera! Please reboot smartphone.")
                cancelButton.label: objectName
                customButton.label: objectName
            },
            ComponentDefinition {
                id: appCover
                source: "AppCover.qml"
            },
            ComponentDefinition {
                id: settingsPageDefinition
                source: "SettingsPage.qml"
            },
            ComponentDefinition {
                id: aboutPageDefinition
                source: "AboutPage.qml"
            }
        ]
    }

    onCreationCompleted: {
        Application.cover = appCover.createObject();
        OrientationSupport.supportedDisplayOrientation = SupportedDisplayOrientation.All;
    }
}
